@@ -2,7 +2,7 @@
 from typing import Optional
 # Third-Party Imports
 # Project Imports
-from handlers.handlers_typing import Handler, HandlerReturn
+from flexceptions.handlers.handlers_typing import Handler, HandlerReturn
 
 
 class BaseFlexception(Exception):
@@ -27,7 +27,7 @@ class BaseFlexception(Exception):
         try:
             return handler(self)
         except TypeError as error:
-            from core_exceptions.wrapped_exceptions import WrappedFlexception
+            from flexceptions import WrappedFlexception
             raise WrappedFlexception(wrapped_exception=error)
 
     def __str__(self) -> str:
